@@ -1,11 +1,9 @@
 package Text::Ngram;
 
-use 5.008008;
+use 5.006;
 use strict;
 use warnings;
 
-use Unicode::CaseFold;
-
 require Exporter;
 
 our @ISA = qw(Exporter);
@@ -13,7 +11,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw( ngram_counts add_to_counts) ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw();
 
-our $VERSION = '0.15_1';
+our $VERSION = '0.09';
 
 =head1 NAME
 
@@ -57,16 +55,15 @@ XSLoader::load('Text::Ngram', $VERSION);
 
 sub _clean_buffer {
     my %config = %{+shift};
-    my $buffer = shift;
-    $buffer = fc $buffer if $config{lowercase};
+    my $buffer = lc shift if $config{lowercase};
     $buffer =~ s/\s+/ /g;
     unless ($config{punctuation}) {
-        if ($config{flankbreaks}) {
-            $buffer =~ s/[^[:alpha:] ]+/ \xff /g;
-        }
-        else {
-            $buffer =~ s/[^[:alpha:] ]+/\xff/g;
-        }
+      if ($config{flankbreaks}) {
+        $buffer =~ s/[^a-z ]+/ \xff /g;
+      }
+      else {
+        $buffer =~ s/[^a-z ]+/\xff/g;
+      }
     }
     $buffer =~ y/ / /s;
     return $buffer;
@@ -74,24 +71,20 @@ sub _clean_buffer {
 
 =head2 ngram_counts
 
-This first function returns a hash reference with the n-gram histogram
+This first function returns a hash reference with the n-gram histogram 
 of the text for the given window size. The default window size is 5.
 
     $href = ngram_counts(\%config, $text, $window_size);
 
-As of version 0.14, the %config may instead be passed in as named arguments:
-
-    $href = ngram_counts($text, $window_size, %config);
-
 The only necessary parameter is $text.
 
-The possible value for %config are:
+The possible value for \%config are:
 
 =head3 flankbreaks
 
 If set to 1 (default), breaks are flanked by spaces; if set to 0,
-they're not. Breaks are punctuation and other non-alphabetic
-characters, which, unless you use C<< punctuation => 0 >> in your
+they're not. Breaks are punctuation and other non-alfabetic
+characters, which, unless you use C<punctuation => 0> in your
 configuration, do not make it into the returned hash.
 
 Here's an example, supposing you're using the default value
@@ -140,7 +133,7 @@ ngrams.  Set to 1 to preserve it.
 
 =head3 spaces
 
-If set to 0 (default is 1), no ngrams containing spaces will be returned.
+If set to 0 default is 1, no ngrams contaning spaces will be returned.
 
    # Get all ngrams of size 3 that do not contain spaces
    $href = ngram_counts( {spaces => 0}, $text, 3);
@@ -156,24 +149,19 @@ avoid calculating the same thing twice is probably this:
 
 sub ngram_counts {
     my %config = (
-                  spaces => 1,
-                  punctuation => 0,
-                  lowercase => 1,
-                  flankbreaks => 1
-                 );
+        spaces => 1,
+        punctuation => 0,
+        lowercase => 1,
+        flankbreaks => 1
+        );
     if (ref($_[0]) eq 'HASH') {
         %config = (%config, %{+shift});
     }
-    elsif (@_ > 2) {
-        %config = (%config, splice @_, (@_ & 1) ? 1 : 2);
-    }
     my ($buffer, $width) = @_;
     $width ||= 5;
     return {} if $width < 1;
     my $href = _process_buffer(_clean_buffer(\%config, $buffer), $width);
-    unless ($config{punctuation}) {
-        for (keys %$href) { delete $href->{$_} if /\xff/ }
-    }
+    for (keys %$href) { delete $href->{$_} if /\xff/ }
     unless ($config{spaces}) {
         for (keys %$href) { delete $href->{$_} if / / }
     }
@@ -240,6 +228,6 @@ Copyright 2004 by Jose Castro
 Copyright 2003 by Simon Cozens
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+it under the same terms as Perl itself. 
 
 =cut
